@@ -1118,9 +1118,7 @@ static int cond_dont_leave_site(url * urlp, cond_info_t * condp)
       UNLOCK_URL(ogp);
     }
 
-    return (urlp->type == gparent->type) &&
-      (url_get_port(urlp) == url_get_port(gparent)) &&
-      !strcmp(url_get_site(urlp), url_get_site(gparent));
+    return url_is_same_site(urlp, gparent);
   }
   else
     return TRUE;
@@ -1161,10 +1159,7 @@ static int cond_dont_leave_dir(url * urlp, cond_info_t * condp)
     if(p)
       len = p - p2;
 
-    return (urlp->type == gparent->type) &&
-      (url_get_port(urlp) == url_get_port(gparent)) &&
-      !strcmp(url_get_site(urlp), url_get_site(gparent)) &&
-      !strncmp(p1, p2, len);
+    return url_is_same_site(urlp, gparent) && !strncmp(p1, p2, len);
   }
   else
     return TRUE;
@@ -1338,10 +1333,7 @@ static int cond_dont_leave_site_enter_dir(url * urlp, cond_info_t * condp)
       if(p)
         len = p - p2;
 
-      return (urlp->type == gparent->type) &&
-        (url_get_port(urlp) == url_get_port(gparent)) &&
-        !strcmp(url_get_site(urlp),
-        url_get_site(gparent)) && !strncmp(p1, p2, len);
+      return url_is_same_site(urlp, gparent) && !strncmp(p1, p2, len);
     }
   }
 
