@@ -176,11 +176,11 @@ static void cfg_version_info(void)
 #else
 #define __SSLIMP "unknown"
 #endif
-  xprintf(0, gettext(" - SSL layer implemneted with %s library\n"), __SSLIMP);
+  xprintf(0, gettext(" - SSL layer implemented with %s library\n"), __SSLIMP);
 #endif
 
 #ifdef SOCKS
-#ifdef SOCKS5
+#ifndef SOCKS5
   xprintf(0, gettext(" - Socks v4 proxy support\n"));
 #else
   xprintf(0, gettext(" - Socks v5 proxy support\n"));
