@@ -89,12 +89,19 @@ extern int h_errno;
 
 #ifndef SOCKS5
 #define connect         Rconnect
+int Rconnect(int sockfd, const struct sockaddr *serv_addr, socklen_t addrlen);
 #define bind            Rbind
+int Rbind(int  sockfd, struct sockaddr *my_addr, socklen_t addrlen);
 #define accept          Raccept
+int Raccept(int s, struct sockaddr *addr, socklen_t *addrlen);
 #define listen          Rlisten
+int Rlisten(int s, int backlog);
 #define select          Rselect
+int  Rselect(int  n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds, struct timeval *timeout);
 #define gethostbyname   Rgethostbyname
+struct hostent *Rgethostbyname(const char *name);
 #define getsockname     Rgetsockname
+int Rgetsockname(int s, struct sockaddr  *name, socklen_t *namelen);
 #endif /* SOCKS5 */
 
 #endif /* SOCKS */
