@@ -391,7 +391,7 @@ void html_parser_parse(html_parser_t * hpinfo)
       continue;
     }
 
-    if((*p == '\"') && tagstart) 
+    if((*p == '\"') && tagstart && !singlequoteintag)
     {
       if(doublequoteintag)
       {
@@ -402,7 +402,7 @@ void html_parser_parse(html_parser_t * hpinfo)
         doublequoteintag = TRUE;
       }
     }
-    else if((*p == '\'') && tagstart) 
+    else if((*p == '\'') && tagstart && !doublequoteintag)
     {
       if(singlequoteintag)
       {
