@@ -518,7 +518,7 @@ lfname *lfname_new(lfname_type type, const char *mpt, const char *str)
     if((p = re_comp(mpt)))
     {
       xprintf(0, gettext("Error compiling regular expression : %s\n"), mpt);
-      xprintf(0, p);
+      xprintf(0, "%s", p);
       free(rv);
       return NULL;
     }
@@ -680,7 +680,7 @@ int lfname_check_pattern(lfname_type type, const char *str)
     if(p)
     {
       xprintf(0, gettext("Error compiling regular expression : %s\n"), str);
-      xprintf(0, p);
+      xprintf(0, "%s", p);
     }
     return p == NULL;
 #elif defined(HAVE_GNU_REGEX)
