@@ -7,7 +7,7 @@
 #include "config.h"
 
 /****************************************************************/
-/* based on document "NTLM Athentication Scheme for HTTP"       */
+/* based on the document "NTLM Athentication Scheme for HTTP"   */
 /* http://www.innovation.ch/java/ntlm.html                      */
 /* by Ronald Tschaler <ronald@innovation.ch>                    */
 /****************************************************************/
@@ -300,6 +300,7 @@ static void ntlm_gen_lm_resp(char *pass, char *nonce, char *buf)
 
   memset(lm_pw, '\0', sizeof(lm_pw));
   strncpy(lm_pw, pass, 14);
+  lm_pw[13] = '\0';
   upperstr(lm_pw);
 
   ntlm_des_enc(lm_pw, magic, lm_hpw);
@@ -512,9 +513,9 @@ char *ntlm_get_t3msg_str(char *domain, char *host, char *user, char *pass,
 /*
  * -1 - failure before sending auth data - http_process_response() can
  *      continue safely
- *  0 - OK - http_process_response() must return immediatly
+ *  0 - OK - http_process_response() must return immediately
  *  1 - failure after sending auth data - http_process_response() must
- *      return immediatly
+ *      return immediately
  */
 int ntlm_negotiate_connection(doc * docp, char *authtag)
 {
@@ -556,6 +557,10 @@ int ntlm_negotiate_connection(doc * docp, char *authtag)
     ai->ntlm_domain : priv_cfg.auth_ntlm_domain;
 
   l = strcspn(cfg.local_host, ".");
+  if (l > 127)
+  {
+    l = 127;
+  }
   strncpy(shost, cfg.local_host, l);
   shost[l] = '\0';
   host = shost;
@@ -723,6 +728,10 @@ int ntlm_negotiate_proxy_connection(doc * docp, char *authtag)
     ai->ntlm_domain : priv_cfg.auth_proxy_ntlm_domain;
 
   l = strcspn(cfg.local_host, ".");
+  if (l > 127)
+  {
+    l = 127;
+  }
   strncpy(shost, cfg.local_host, l);
   shost[l] = '\0';
   host = shost;
