@@ -763,11 +763,22 @@ char *url_to_absolute_url(char *base, char *baset, url * parent, char *act)
     else
     {
       strcpy(pom, base);
-      ri = strrchr(pom, '/');
-      if(ri)
-        strcpy(ri + 1, purl->p.file.filename);
+      if(!*purl->p.file.filename && purl->p.file.searchstr && parent->type == URLT_HTTP)
+      {
+        ri = strrchr(pom, '/');
+        if(ri)
+          strcpy(ri, parent->p.http.document);
+        else
+          strcat(pom, parent->p.http.document);
+      }
       else
-        strcat(pom, purl->p.file.filename);
+      {
+        ri = strrchr(pom, '/');
+        if(ri)
+          strcpy(ri + 1, purl->p.file.filename);
+        else
+          strcat(pom, purl->p.file.filename);
+      }
 
       if((parent->status & URL_REDIRECT) &&
         (strlen(purl->p.file.filename) >= strlen(priv_cfg.index_name)) &&
@@ -1921,7 +1932,7 @@ char *url_to_urlstr(url * urlp, int wa)
 
     sprintf(retv, "%s%s%s%s%s%s", prottable[URLT_FILE].typestr, p,
       urlp->p.file.searchstr ? "?" : "",
-      urlp->p.file.searchstr ? urlp->p.http.searchstr : "",
+      urlp->p.file.searchstr ? urlp->p.file.searchstr : "",
       urlp->p.file.anchor_name ? "#" : "",
       urlp->p.file.anchor_name ? urlp->p.file.anchor_name : "");
 
@@ -2318,12 +2329,22 @@ int url_is_dir_index(url * urlp)
   return ((urlp->type == URLT_HTTP || urlp->type == URLT_HTTPS) &&
     tl_is_dirname(urlp->p.http.document)) ||
     ((urlp->type == URLT_FTP || urlp->type == URLT_FTPS) && urlp->p.ftp.dir);
+}
 
+/* Check if URL is on same site. Be careful not to disallow
+   protocol changes like HTTP to HTTPS. */
+int url_is_same_site(url * urla, url * urlb)
+{
+  return
+  /* (urla->type == urlb->type) &&
+     (url_get_port(urla) == url_get_port(urlb)) && */
+   !strcmp(url_get_site(urla), url_get_site(urlb));
 }
 
 /**************************************************/
+/* FIXME: Translate me                            */
 /* absolutna cesta k dokumentu z lokalneho stromu */
-/* ktory je referencovany relativne     */
+/* ktory je referencovany relativne               */
 /**************************************************/
 char *get_redirect_abs_path(url * rurl, char *fstr)
 {
